@@ -155,12 +155,7 @@ void EditBase<T>::undo()
 
 	// Send signals.
 	DiveField id = fieldId();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-	emit diveListNotifier.divesChanged(QVector<dive *>(dives.begin(), dives.end()), id);
-#else
-	emit diveListNotifier.divesChanged(QVector<dive *>::fromStdVector(dives), id);
-#endif
-
+	emit diveListNotifier.divesChanged(stdToQt<dive *>(dives), id);
 	setSelection(selectedDives, current);
 }
 
@@ -551,11 +546,7 @@ void EditTagsBase::undo()
 
 	// Send signals.
 	DiveField id = fieldId();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-	emit diveListNotifier.divesChanged(QVector<dive *>(dives.begin(), dives.end()), id);
-#else
-	emit diveListNotifier.divesChanged(QVector<dive *>::fromStdVector(dives), id);
-#endif
+	emit diveListNotifier.divesChanged(stdToQt<dive *>(dives), id);
 	setSelection(selectedDives, current);
 }
 
@@ -1039,9 +1030,9 @@ AddCylinder::AddCylinder(bool currentDiveOnly) :
 	if (dives.empty())
 		return;
 	else if (dives.size() == 1)
-		setText(tr("Add cylinder"));
+		setText(Command::Base::tr("Add cylinder"));
 	else
-		setText(tr("Add cylinder (%n dive(s))", "", dives.size()));
+		setText(Command::Base::tr("Add cylinder (%n dive(s))", "", dives.size()));
 	cyl = create_new_cylinder(dives[0]);
 }
 
@@ -1160,9 +1151,9 @@ RemoveCylinder::RemoveCylinder(int index, bool currentDiveOnly) :
 	EditCylinderBase(index, currentDiveOnly, true, SAME_TYPE | SAME_PRESS | SAME_GAS)
 {
 	if (dives.size() == 1)
-		setText(tr("Remove cylinder"));
+		setText(Command::Base::tr("Remove cylinder"));
 	else
-		setText(tr("Remove cylinder (%n dive(s))", "", dives.size()));
+		setText(Command::Base::tr("Remove cylinder (%n dive(s))", "", dives.size()));
 }
 
 void RemoveCylinder::undo()
@@ -1210,9 +1201,9 @@ EditCylinder::EditCylinder(int index, cylinder_t cylIn, EditCylinderType typeIn,
 		return;
 
 	if (dives.size() == 1)
-		setText(tr("Edit cylinder"));
+		setText(Command::Base::tr("Edit cylinder"));
 	else
-		setText(tr("Edit cylinder (%n dive(s))", "", dives.size()));
+		setText(Command::Base::tr("Edit cylinder (%n dive(s))", "", dives.size()));
 
 	// Try to untranslate the cylinder type
 	QString description = cylIn.type.description;
