@@ -76,7 +76,8 @@ out:
 }
 
 
-static void zip_read(struct zip_file *file, const char *filename, struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites)
+static void zip_read(struct zip_file *file, const char *filename, struct dive_table *table, struct trip_table *trips,
+		     struct dive_site_table *sites, struct device_table *devices, struct filter_preset_table *filter_presets)
 {
 	int size = 1024, n, read = 0;
 	char *mem = malloc(size);
@@ -87,11 +88,12 @@ static void zip_read(struct zip_file *file, const char *filename, struct dive_ta
 		mem = realloc(mem, size);
 	}
 	mem[read] = 0;
-	(void) parse_xml_buffer(filename, mem, read, table, trips, sites, NULL);
+	(void) parse_xml_buffer(filename, mem, read, table, trips, sites, devices, filter_presets, NULL);
 	free(mem);
 }
 
-int try_to_open_zip(const char *filename, struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites)
+int try_to_open_zip(const char *filename, struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites,
+		    struct device_table *devices, struct filter_preset_table *filter_presets)
 {
 	int success = 0;
 	/* Grr. libzip needs to re-open the file, it can't take a buffer */
@@ -106,7 +108,7 @@ int try_to_open_zip(const char *filename, struct dive_table *table, struct trip_
 			/* skip parsing the divelogs.de pictures */
 			if (strstr(zip_get_name(zip, index, 0), "pictures/"))
 				continue;
-			zip_read(file, filename, table, trips, sites);
+			zip_read(file, filename, table, trips, sites, devices, filter_presets);
 			zip_fclose(file);
 			success++;
 		}
@@ -126,8 +128,8 @@ static int db_test_func(void *param, int columns, char **data, char **column)
 	return *data[0] == '0';
 }
 
-
-static int try_to_open_db(const char *filename, struct memblock *mem, struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites)
+static int try_to_open_db(const char *filename, struct memblock *mem, struct dive_table *table, struct trip_table *trips,
+			  struct dive_site_table *sites, struct device_table *devices)
 {
 	sqlite3 *handle;
 	char dm4_test[] = "select count(*) from sqlite_master where type='table' and name='Dive' and sql like '%ProfileBlob%'";
@@ -149,7 +151,7 @@ static int try_to_open_db(const char *filename, struct memblock *mem, struct div
 	/* Testing if DB schema resembles Suunto DM5 database format */
 	retval = sqlite3_exec(handle, dm5_test, &db_test_func, 0, NULL);
 	if (!retval) {
-		retval = parse_dm5_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites);
+		retval = parse_dm5_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites, devices);
 		sqlite3_close(handle);
 		return retval;
 	}
@@ -157,7 +159,7 @@ static int try_to_open_db(const char *filename, struct memblock *mem, struct div
 	/* Testing if DB schema resembles Suunto DM4 database format */
 	retval = sqlite3_exec(handle, dm4_test, &db_test_func, 0, NULL);
 	if (!retval) {
-		retval = parse_dm4_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites);
+		retval = parse_dm4_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites, devices);
 		sqlite3_close(handle);
 		return retval;
 	}
@@ -165,7 +167,7 @@ static int try_to_open_db(const char *filename, struct memblock *mem, struct div
 	/* Testing if DB schema resembles Shearwater database format */
 	retval = sqlite3_exec(handle, shearwater_test, &db_test_func, 0, NULL);
 	if (!retval) {
-		retval = parse_shearwater_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites);
+		retval = parse_shearwater_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites, devices);
 		sqlite3_close(handle);
 		return retval;
 	}
@@ -173,7 +175,7 @@ static int try_to_open_db(const char *filename, struct memblock *mem, struct div
 	/* Testing if DB schema resembles Shearwater cloud database format */
 	retval = sqlite3_exec(handle, shearwater_cloud_test, &db_test_func, 0, NULL);
 	if (!retval) {
-		retval = parse_shearwater_cloud_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites);
+		retval = parse_shearwater_cloud_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites, devices);
 		sqlite3_close(handle);
 		return retval;
 	}
@@ -181,7 +183,7 @@ static int try_to_open_db(const char *filename, struct memblock *mem, struct div
 	/* Testing if DB schema resembles Atomic Cobalt database format */
 	retval = sqlite3_exec(handle, cobalt_test, &db_test_func, 0, NULL);
 	if (!retval) {
-		retval = parse_cobalt_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites);
+		retval = parse_cobalt_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites, devices);
 		sqlite3_close(handle);
 		return retval;
 	}
@@ -189,7 +191,7 @@ static int try_to_open_db(const char *filename, struct memblock *mem, struct div
 	/* Testing if DB schema resembles Divinglog database format */
 	retval = sqlite3_exec(handle, divinglog_test, &db_test_func, 0, NULL);
 	if (!retval) {
-		retval = parse_divinglog_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites);
+		retval = parse_divinglog_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites, devices);
 		sqlite3_close(handle);
 		return retval;
 	}
@@ -197,7 +199,7 @@ static int try_to_open_db(const char *filename, struct memblock *mem, struct div
 	/* Testing if DB schema resembles Seac database format */
 	retval = sqlite3_exec(handle, seacsync_test, &db_test_func, 0, NULL);
 	if (!retval) {
-		retval = parse_seac_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites);
+		retval = parse_seac_buffer(handle, filename, mem->buffer, mem->size, table, trips, sites, devices);
 		sqlite3_close(handle);
 		return retval;
 	}
@@ -225,7 +227,8 @@ static int try_to_open_db(const char *filename, struct memblock *mem, struct div
  * Followed by the data values (all comma-separated, all one long line).
  */
 static int open_by_filename(const char *filename, const char *fmt, struct memblock *mem,
-			    struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites)
+			    struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites,
+			    struct device_table *devices, struct filter_preset_table *filter_presets)
 {
 	// hack to be able to provide a comment for the translated string
 	static char *csv_warning = QT_TRANSLATE_NOOP3("gettextFromC",
@@ -234,7 +237,7 @@ static int open_by_filename(const char *filename, const char *fmt, struct memblo
 
 	/* Suunto Dive Manager files: SDE, ZIP; divelogs.de files: DLD */
 	if (!strcasecmp(fmt, "SDE") || !strcasecmp(fmt, "ZIP") || !strcasecmp(fmt, "DLD"))
-		return try_to_open_zip(filename, table, trips, sites);
+		return try_to_open_zip(filename, table, trips, sites, devices, filter_presets);
 
 	/* CSV files */
 	if (!strcasecmp(fmt, "CSV"))
@@ -255,17 +258,19 @@ static int open_by_filename(const char *filename, const char *fmt, struct memblo
 	return 0;
 }
 
-static int parse_file_buffer(const char *filename, struct memblock *mem, struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites)
+static int parse_file_buffer(const char *filename, struct memblock *mem, struct dive_table *table,
+			     struct trip_table *trips, struct dive_site_table *sites,
+			     struct device_table *devices, struct filter_preset_table *filter_presets)
 {
 	int ret;
 	char *fmt = strrchr(filename, '.');
-	if (fmt && (ret = open_by_filename(filename, fmt + 1, mem, table, trips, sites)) != 0)
+	if (fmt && (ret = open_by_filename(filename, fmt + 1, mem, table, trips, sites, devices, filter_presets)) != 0)
 		return ret;
 
 	if (!mem->size || !mem->buffer)
 		return report_error("Out of memory parsing file %s\n", filename);
 
-	return parse_xml_buffer(filename, mem->buffer, mem->size, table, trips, sites, NULL);
+	return parse_xml_buffer(filename, mem->buffer, mem->size, table, trips, sites, devices, filter_presets, NULL);
 }
 
 int check_git_sha(const char *filename, struct git_repository **git_p, const char **branch_p)
@@ -302,7 +307,8 @@ int check_git_sha(const char *filename, struct git_repository **git_p, const cha
 	return 1;
 }
 
-int parse_file(const char *filename, struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites)
+int parse_file(const char *filename, struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites,
+	       struct device_table *devices, struct filter_preset_table *filter_presets)
 {
 	struct git_repository *git;
 	const char *branch = NULL;
@@ -319,7 +325,7 @@ int parse_file(const char *filename, struct dive_table *table, struct trip_table
 		return -1;
 	}
 	if (git)
-		return git_load_dives(git, branch, table, trips, sites);
+		return git_load_dives(git, branch, table, trips, sites, devices, filter_presets);
 
 	if ((ret = readfile(filename, &mem)) < 0) {
 		/* we don't want to display an error if this was the default file  */
@@ -333,7 +339,7 @@ int parse_file(const char *filename, struct dive_table *table, struct trip_table
 
 	fmt = strrchr(filename, '.');
 	if (fmt && (!strcasecmp(fmt + 1, "DB") || !strcasecmp(fmt + 1, "BAK") || !strcasecmp(fmt + 1, "SQL"))) {
-		if (!try_to_open_db(filename, &mem, table, trips, sites)) {
+		if (!try_to_open_db(filename, &mem, table, trips, sites, devices)) {
 			free(mem.buffer);
 			return 0;
 		}
@@ -341,7 +347,7 @@ int parse_file(const char *filename, struct dive_table *table, struct trip_table
 
 	/* Divesoft Freedom */
 	if (fmt && (!strcasecmp(fmt + 1, "DLF"))) {
-		ret = parse_dlf_buffer(mem.buffer, mem.size, table, trips, sites);
+		ret = parse_dlf_buffer(mem.buffer, mem.size, table, trips, sites, devices);
 		free(mem.buffer);
 		return ret;
 	}
@@ -355,9 +361,9 @@ int parse_file(const char *filename, struct dive_table *table, struct trip_table
 		wl_name = strcat(wl_name, ".add");
 		if((ret = readfile(wl_name, &wl_mem)) < 0) {
 			fprintf(stderr, "No file %s found. No WLog extensions.\n", wl_name);
-			ret = datatrak_import(&mem, NULL, table, trips, sites);
+			ret = datatrak_import(&mem, NULL, table, trips, sites, devices);
 		} else {
-			ret = datatrak_import(&mem, &wl_mem, table, trips, sites);
+			ret = datatrak_import(&mem, &wl_mem, table, trips, sites, devices);
 			free(wl_mem.buffer);
 		}
 		free(mem.buffer);
@@ -372,7 +378,7 @@ int parse_file(const char *filename, struct dive_table *table, struct trip_table
 		return 0;
 	}
 
-	ret = parse_file_buffer(filename, &mem, table, trips, sites);
+	ret = parse_file_buffer(filename, &mem, table, trips, sites, devices, filter_presets);
 	free(mem.buffer);
 	return ret;
 }
