@@ -8,7 +8,6 @@
 #include "gettextfromc.h"
 #include "statistics.h"
 #include "membuffer.h"
-#include "subsurfacesysinfo.h"
 #include "version.h"
 #include "errorhelper.h"
 #include "planner.h"
@@ -19,9 +18,11 @@
 #include "exif.h"
 #include "file.h"
 #include "picture.h"
+#include "selection.h"
 #include "tag.h"
 #include "trip.h"
 #include "imagedownloader.h"
+#include "xmlparams.h"
 #include <QFile>
 #include <QRegExp>
 #include <QDir>
@@ -38,6 +39,9 @@
 #include <QProgressDialog>	// TODO: remove with convertThumbnails()
 #include <cstdarg>
 #include <cstdint>
+#ifdef Q_OS_UNIX
+#include <sys/utsname.h>
+#endif
 
 #include <libxslt/documents.h>
 
@@ -103,11 +107,11 @@ QString printGPSCoords(const location_t *location)
 		lonmin = (lon % 1000000U) * 60U;
 		latsec = (latmin % 1000000) * 60;
 		lonsec = (lonmin % 1000000) * 60;
-		result.sprintf("%u°%02d\'%06.3f\"%s %u°%02d\'%06.3f\"%s",
+		result.asprintf("%u°%02d\'%06.3f\"%s %u°%02d\'%06.3f\"%s",
 			       latdeg, latmin / 1000000, latsec / 1000000, qPrintable(lath),
 			       londeg, lonmin / 1000000, lonsec / 1000000, qPrintable(lonh));
 	} else {
-		result.sprintf("%f %f", (double) lat / 1000000.0, (double) lon / 1000000.0);
+		result.asprintf("%f %f", (double) lat / 1000000.0, (double) lon / 1000000.0);
 	}
 	return result;
 }
@@ -387,12 +391,9 @@ static bool lessThan(const QPair<QString, int> &a, const QPair<QString, int> &b)
 
 QVector<QPair<QString, int>> selectedDivesGasUsed()
 {
-	int i, j;
-	struct dive *d;
+	int j;
 	QMap<QString, int> gasUsed;
-	for_each_dive (i, d) {
-		if (!d->selected)
-			continue;
+	for (dive *d: getDiveSelection()) {
 		volume_t *diveGases = get_gas_used(d);
 		for (j = 0; j < d->cylinders.nr; j++) {
 			if (diveGases[j].mliter) {
@@ -421,11 +422,19 @@ QString getUserAgent()
 #else
 	QString userAgent = QString("Subsurface:%1:").arg(subsurface_canonical_version());
 #endif
-	userAgent.append(SubsurfaceSysInfo::prettyOsName().replace(':', ' ') + ":");
-	arch = SubsurfaceSysInfo::buildCpuArchitecture().replace(':', ' ');
+	QString prettyOsName = QSysInfo::prettyProductName();
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC) && !defined(Q_OS_ANDROID)
+	// QSysInfo::kernelType() returns lowercase ("linux" instead of "Linux")
+	struct utsname u;
+	if (uname(&u) == 0)
+		prettyOsName = QString::fromLatin1(u.sysname) + QLatin1String(" (") + prettyOsName + QLatin1Char(')');
+#endif
+
+	userAgent.append(prettyOsName.replace(':', ' ') + ":");
+	arch = QSysInfo::buildCpuArchitecture().replace(':', ' ');
 	userAgent.append(arch);
 	if (arch == "i386")
-		userAgent.append("/" + SubsurfaceSysInfo::currentCpuArchitecture());
+		userAgent.append("/" + QSysInfo::currentCpuArchitecture());
 	userAgent.append(":" + getUiLanguage());
 	return userAgent;
 
@@ -1018,15 +1027,23 @@ extern "C" char *get_current_date()
 	return copy_qstring(current_date);
 }
 
-QString get_trip_date_string(timestamp_t when, int nr, bool getday)
+QString get_trip_string(const dive_trip *trip)
 {
+	if (!trip)
+		return QString();
+
+	int nr = trip->dives.nr;
+	timestamp_t when = trip_date(trip);
+	bool getday = trip_is_single_day(trip);
+
 	QDateTime localTime = timestampToDateTime(when);
 
+	QString prefix = !empty_string(trip->location) ? QString(trip->location) + ", " : QString();
 	QString suffix = " " + gettextFromC::tr("(%n dive(s))", "", nr);
 	if (getday)
-		return loc.toString(localTime, prefs.date_format) + suffix;
+		return prefix + loc.toString(localTime, prefs.date_format) + suffix;
 	else
-		return loc.toString(localTime, "MMM yyyy") + suffix;
+		return prefix + loc.toString(localTime, "MMM yyyy") + suffix;
 }
 
 static QMutex hashOfMutex;
@@ -1253,9 +1270,15 @@ QString get_taglist_string(struct tag_entry *tag_list)
 	return ret;
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+#define SKIP_EMPTY Qt::SkipEmptyParts
+#else
+#define SKIP_EMPTY QString::SkipEmptyParts
+#endif
+
 QStringList stringToList(const QString &s)
 {
-	QStringList res = s.split(",", QString::SkipEmptyParts);
+	QStringList res = s.split(",", SKIP_EMPTY);
 	for (QString &str: res)
 		str = str.trimmed();
 	return res;
@@ -1468,7 +1491,7 @@ QString getUUID()
 	return uuidString;
 }
 
-int parse_seabear_header(const char *filename, char **params, int pnr)
+void parse_seabear_header(const char *filename, struct xml_params *params)
 {
 	QFile f(filename);
 
@@ -1481,8 +1504,8 @@ int parse_seabear_header(const char *filename, char **params, int pnr)
 
 	while ((parseLine = f.readLine().trimmed()).length() > 0 && !f.atEnd()) {
 		if (parseLine.contains("//DIVE NR: ")) {
-			params[pnr++] = strdup("diveNro");
-			params[pnr++] = copy_qstring(parseLine.replace(QString::fromLatin1("//DIVE NR: "), QString::fromLatin1("")));
+			xml_params_add(params, "diveNro",
+				       qPrintable(parseLine.replace(QString::fromLatin1("//DIVE NR: "), QString::fromLatin1(""))));
 			break;
 		}
 	}
@@ -1496,8 +1519,9 @@ int parse_seabear_header(const char *filename, char **params, int pnr)
 
 	while ((parseLine = f.readLine().trimmed()).length() > 0 && !f.atEnd()) {
 		if (parseLine.contains("//Hardware Version: ")) {
-			params[pnr++] = strdup("hw");
-			params[pnr++] = copy_qstring(parseLine.replace(QString::fromLatin1("//Hardware Version: "), QString::fromLatin1("\"Seabear ")).trimmed().append("\""));
+			xml_params_add(params, "hw",
+				       qPrintable(parseLine.replace(QString::fromLatin1("//Hardware Version: "),
+						  QString::fromLatin1("\"Seabear ")).trimmed().append("\"")));
 			break;
 		}
 	}
@@ -1509,8 +1533,8 @@ int parse_seabear_header(const char *filename, char **params, int pnr)
 
 	while ((parseLine = f.readLine().trimmed()).length() > 0 && !f.atEnd()) {
 		if (parseLine.contains("//Log interval: ")) {
-			params[pnr++] = strdup("delta");
-			params[pnr++] = copy_qstring(parseLine.remove(QString::fromLatin1("//Log interval: ")).trimmed().remove(QString::fromLatin1(" s")));
+			xml_params_add(params, "delta",
+				       qPrintable(parseLine.remove(QString::fromLatin1("//Log interval: ")).trimmed().remove(QString::fromLatin1(" s"))));
 			break;
 		}
 	}
@@ -1524,8 +1548,8 @@ int parse_seabear_header(const char *filename, char **params, int pnr)
 	while ((parseLine = f.readLine().trimmed()).length() > 0 && !f.atEnd()) {
 		QString needle = "//Mode: ";
 		if (parseLine.contains(needle)) {
-			params[pnr++] = strdup("diveMode");
-			params[pnr++] = copy_qstring(parseLine.replace(needle, QString::fromLatin1("")).prepend("\"").append("\""));
+			xml_params_add(params, "diveMode",
+				       qPrintable(parseLine.replace(needle, QString::fromLatin1("")).prepend("\"").append("\"")));
 		}
 	}
 	f.seek(0);
@@ -1537,8 +1561,8 @@ int parse_seabear_header(const char *filename, char **params, int pnr)
 	while ((parseLine = f.readLine().trimmed()).length() > 0 && !f.atEnd()) {
 		QString needle = "//Firmware Version: ";
 		if (parseLine.contains(needle)) {
-			params[pnr++] = strdup("Firmware");
-			params[pnr++] = copy_qstring(parseLine.replace(needle, QString::fromLatin1("")).prepend("\"").append("\""));
+			xml_params_add(params, "Firmware",
+				       qPrintable(parseLine.replace(needle, QString::fromLatin1("")).prepend("\"").append("\"")));
 		}
 	}
 	f.seek(0);
@@ -1546,8 +1570,8 @@ int parse_seabear_header(const char *filename, char **params, int pnr)
 	while ((parseLine = f.readLine().trimmed()).length() > 0 && !f.atEnd()) {
 		QString needle = "//Serial number: ";
 		if (parseLine.contains(needle)) {
-			params[pnr++] = strdup("Serial");
-			params[pnr++] = copy_qstring(parseLine.replace(needle, QString::fromLatin1("")).prepend("\"").append("\""));
+			xml_params_add(params, "Serial",
+				       qPrintable(parseLine.replace(needle, QString::fromLatin1("")).prepend("\"").append("\"")));
 		}
 	}
 	f.seek(0);
@@ -1555,8 +1579,8 @@ int parse_seabear_header(const char *filename, char **params, int pnr)
 	while ((parseLine = f.readLine().trimmed()).length() > 0 && !f.atEnd()) {
 		QString needle = "//GF: ";
 		if (parseLine.contains(needle)) {
-			params[pnr++] = strdup("GF");
-			params[pnr++] = copy_qstring(parseLine.replace(needle, QString::fromLatin1("")).prepend("\"").append("\""));
+			xml_params_add(params, "GF",
+				       qPrintable(parseLine.replace(needle, QString::fromLatin1("")).prepend("\"").append("\"")));
 		}
 	}
 	f.seek(0);
@@ -1574,36 +1598,26 @@ int parse_seabear_header(const char *filename, char **params, int pnr)
 	unsigned short index = 0;
 	for (const QString &columnText: currColumns) {
 		if (columnText == "Time") {
-			params[pnr++] = strdup("timeField");
-			params[pnr++] = intdup(index++);
+			xml_params_add_int(params, "timeField", index++);
 		} else if (columnText == "Depth") {
-			params[pnr++] = strdup("depthField");
-			params[pnr++] = intdup(index++);
+			xml_params_add_int(params, "depthField", index++);
 		} else if (columnText == "Temperature") {
-			params[pnr++] = strdup("tempField");
-			params[pnr++] = intdup(index++);
+			xml_params_add_int(params, "tempField", index++);
 		} else if (columnText == "NDT") {
-			params[pnr++] = strdup("ndlField");
-			params[pnr++] = intdup(index++);
+			xml_params_add_int(params, "ndlField", index++);
 		} else if (columnText == "TTS") {
-			params[pnr++] = strdup("ttsField");
-			params[pnr++] = intdup(index++);
+			xml_params_add_int(params, "ttsField", index++);
 		} else if (columnText == "pO2_1") {
-			params[pnr++] = strdup("o2sensor1Field");
-			params[pnr++] = intdup(index++);
+			xml_params_add_int(params, "o2sensor1Field", index++);
 		} else if (columnText == "pO2_2") {
-			params[pnr++] = strdup("o2sensor2Field");
-			params[pnr++] = intdup(index++);
+			xml_params_add_int(params, "o2sensor2Field", index++);
 		} else if (columnText == "pO2_3") {
-			params[pnr++] = strdup("o2sensor3Field");
-			params[pnr++] = intdup(index++);
+			xml_params_add_int(params, "o2sensor3Field", index++);
 		} else if (columnText == "Ceiling") {
 			/* TODO: Add support for dive computer reported ceiling*/
-			params[pnr++] = strdup("ceilingField");
-			params[pnr++] = intdup(index++);
+			xml_params_add_int(params, "ceilingField", index++);
 		} else if (columnText == "Tank pressure") {
-			params[pnr++] = strdup("pressureField");
-			params[pnr++] = intdup(index++);
+			xml_params_add_int(params, "pressureField", index++);
 		} else {
 			// We do not know about this value
 			qDebug() << "Seabear import found an un-handled field: " << columnText;
@@ -1611,25 +1625,12 @@ int parse_seabear_header(const char *filename, char **params, int pnr)
 	}
 
 	/* Separator is ';' and the index for that in DiveLogImportDialog constructor is 2 */
-	params[pnr++] = strdup("separatorIndex");
-	params[pnr++] = intdup(2);
+	xml_params_add_int(params, "separatorIndex", 2);
 
 	/* And metric units */
-	params[pnr++] = strdup("units");
-	params[pnr++] = intdup(0);
+	xml_params_add_int(params, "units", 0);
 
-	params[pnr] = NULL;
 	f.close();
-	return pnr;
-}
-
-char *intdup(int index)
-{
-	char tmpbuf[21];
-
-	snprintf(tmpbuf, sizeof(tmpbuf) - 2, "%d", index);
-	tmpbuf[20] = 0;
-	return strdup(tmpbuf);
 }
 
 extern "C" void print_qt_versions()
