@@ -8,6 +8,8 @@
 #include "subsurface-time.h"
 
 struct picture;
+struct dive_trip;
+struct xml_params;
 
 // 1) Types
 
@@ -43,7 +45,6 @@ extern const QStringList videoExtensionsList;
 QStringList mediaExtensionFilters();
 QStringList imageExtensionFilters();
 QStringList videoExtensionFilters();
-char *intdup(int index);
 char *copy_qstring(const QString &);
 QString get_depth_string(depth_t depth, bool showunit = false, bool showdecimal = true);
 QString get_depth_string(int mm, bool showunit = false, bool showdecimal = true);
@@ -79,7 +80,7 @@ QString get_dive_date_string(timestamp_t when);
 QString get_first_dive_date_string();
 QString get_last_dive_date_string();
 QString get_short_dive_date_string(timestamp_t when);
-QString get_trip_date_string(timestamp_t when, int nr, bool getday);
+QString get_trip_string(const dive_trip *trip);
 QString getUiLanguage();
 void initUiLanguage();
 QLocale getLocale();
@@ -138,6 +139,7 @@ bool canReachCloudServer();
 void updateWindowTitle();
 void subsurface_mkdir(const char *dir);
 char *get_file_name(const char *fileName);
+void set_filename(const char *filename);
 void copy_image_and_overwrite(const char *cfileName, const char *path, const char *cnewName);
 char *move_away(const char *path);
 const char *local_file_path(struct picture *picture);
@@ -146,7 +148,7 @@ char *hashfile_name_string();
 char *picturedir_string();
 const char *subsurface_user_agent();
 enum deco_mode decoMode();
-int parse_seabear_header(const char *filename, char **params, int pnr);
+void parse_seabear_header(const char *filename, struct xml_params *params);
 char *get_current_date();
 time_t get_dive_datetime_from_isostring(char *when);
 void print_qt_versions();
