@@ -18,10 +18,15 @@
 
 #include "dive.h"
 #include "divesite.h"
+#include "filterconstraint.h"
+#include "filterpreset.h"
+#include "sample.h"
 #include "subsurface-string.h"
 #include "trip.h"
 #include "device.h"
 #include "errorhelper.h"
+#include "event.h"
+#include "extradata.h"
 #include "membuffer.h"
 #include "git-access.h"
 #include "version.h"
@@ -843,21 +848,22 @@ static void save_units(void *_b)
 			   prefs.units.vertical_speed_time == SECONDS ? "SECONDS" : "MINUTES");
 }
 
-static void save_one_device(void *_b, const char *model, uint32_t deviceid,
-	const char *nickname, const char *serial, const char *firmware)
+static void save_one_device(struct membuffer *b, const struct device *d)
 {
-	struct membuffer *b = _b;
-
-	if (nickname && !strcmp(model, nickname))
+	const char *model = device_get_model(d);
+	const char *nickname = device_get_nickname(d);
+	const char *serial = device_get_serial(d);
+	const char *firmware = device_get_firmware(d);
+	if (!empty_string(nickname) && !strcmp(model, nickname))
 		nickname = NULL;
-	if (serial && !*serial) serial = NULL;
-	if (firmware && !*firmware) firmware = NULL;
-	if (nickname && !*nickname) nickname = NULL;
+	if (empty_string(serial)) serial = NULL;
+	if (empty_string(firmware)) firmware = NULL;
+	if (empty_string(nickname)) nickname = NULL;
 	if (!nickname && !serial && !firmware)
 		return;
 
 	show_utf8(b, "divecomputerid ", model, "");
-	put_format(b, " deviceid=%08x", deviceid);
+	put_format(b, " deviceid=%08x", device_get_id(d));
 	show_utf8(b, " serial=", serial, "");
 	show_utf8(b, " firmware=", firmware, "");
 	show_utf8(b, " nickname=", nickname, "");
@@ -869,7 +875,8 @@ static void save_settings(git_repository *repo, struct dir *tree)
 	struct membuffer b = { 0 };
 
 	put_format(&b, "version %d\n", DATAFORMAT_VERSION);
-	call_for_each_dc(&b, save_one_device, false);
+	for (int i = 0; i < nr_devices(&device_table); i++)
+		save_one_device(&b, get_device(&device_table, i));
 	cond_put_format(autogroup, &b, "autogroup\n");
 	save_units(&b);
 	if (prefs.tankbar)
@@ -916,6 +923,88 @@ static void save_divesites(git_repository *repo, struct dir *tree)
 	}
 }
 
+/*
+ * Format a filter constraint line to the membuffer b.
+ * The format is
+ *	constraint type "type of the constraint" [stringmode "string mode"] [rangemode "rangemode"] [negate] data "data of the constraint".
+ * where brackets indicate optional blocks.
+ * For possible types and how data is interpreted see core/filterconstraint.[c|h]
+ * Whether stringmode or rangemode exist depends on the type of the constraint.
+ * Any constraint can be negated.
+ */
+static void format_one_filter_constraint(int preset_id, int constraint_id, struct membuffer *b)
+{
+	const struct filter_constraint *constraint = filter_preset_constraint(preset_id, constraint_id);
+	const char *type = filter_constraint_type_to_string(constraint->type);
+	char *data;
+
+	show_utf8(b, "constraint type=", type, "");
+	if (filter_constraint_has_string_mode(constraint->type)) {
+		const char *mode = filter_constraint_string_mode_to_string(constraint->string_mode);
+		show_utf8(b, " stringmode=", mode, "");
+	}
+	if (filter_constraint_has_range_mode(constraint->type)) {
+		const char *mode = filter_constraint_range_mode_to_string(constraint->range_mode);
+		show_utf8(b, " rangemode=", mode, "");
+	}
+	if (constraint->negate)
+		put_format(b, " negate");
+	data = filter_constraint_data_to_string(constraint);
+	show_utf8(b, " data=", data, "\n");
+	free(data);
+}
+
+/*
+ * Write a filter constraint to the membuffer b.
+ * Each line starts with a type, which is either "name", "fulltext" or "constraint".
+ * There must be one "name" entry, zero or one "fulltext" entries and an arbitrary number of "contraint" entries.
+ * The "name" entry gives the name of the filter constraint.
+ * The "fulltext" entry has the format
+ *	fulltext mode "fulltext mode" query "the query as entered by the user"
+ * The format of the "constraint" entry is described in the format_one_filter_constraint() function.
+ */
+static void format_one_filter_preset(int preset_id, struct membuffer *b)
+{
+	char *name, *fulltext;
+
+	name = filter_preset_name(preset_id);
+	show_utf8(b, "name ", name, "\n");
+	free(name);
+
+	fulltext = filter_preset_fulltext_query(preset_id);
+	if (!empty_string(fulltext)) {
+		show_utf8(b, "fulltext mode=", filter_preset_fulltext_mode(preset_id), "");
+		show_utf8(b, " query=", fulltext, "\n");
+	}
+	free(fulltext);
+
+	for (int i = 0; i < filter_preset_constraint_count(preset_id); i++)
+		format_one_filter_constraint(preset_id, i, b);
+}
+
+static void save_filter_presets(git_repository *repo, struct dir *tree)
+{
+	struct membuffer dirname = { 0 };
+	struct dir *filter_dir;
+	put_format(&dirname, "02-Filterpresets");
+	filter_dir = new_directory(repo, tree, &dirname);
+	free_buffer(&dirname);
+
+	for (int i = 0; i < filter_presets_count(); i++)
+	{
+		struct membuffer preset_name = { 0 };
+		struct membuffer preset_buffer = { 0 };
+
+		put_format(&preset_name, "Preset-%03d", i);
+		format_one_filter_preset(i, &preset_buffer);
+
+		blob_insert(repo, filter_dir, &preset_buffer, mb_cstring(&preset_name));
+
+		free_buffer(&preset_name);
+		free_buffer(&preset_buffer);
+	}
+}
+
 static int create_git_tree(git_repository *repo, struct dir *root, bool select_only, bool cached_ok)
 {
 	int i;
@@ -926,6 +1015,7 @@ static int create_git_tree(git_repository *repo, struct dir *root, bool select_o
 	save_settings(repo, root);
 
 	save_divesites(repo, root);
+	save_filter_presets(repo, root);
 
 	for (i = 0; i < trip_table.nr; ++i)
 		trip_table.trips[i]->saved = 0;
