@@ -10,6 +10,8 @@
 
 #include <QObject>
 
+struct device;
+
 // Dive and trip fields that can be edited. Use bit fields so that we can pass multiple fields at once.
 // Provides an inlined flag-based constructur because sadly C-style designated initializers are only supported since C++20.
 struct DiveField {
@@ -125,6 +127,16 @@ signals:
 	void picturesRemoved(dive *d, QVector<QString> filenames);
 	void picturesAdded(dive *d, QVector<PictureObj> pics);
 
+	// Devices related signals
+	void deviceAdded(int index);
+	void deviceDeleted(int index);
+	void deviceEdited(int index);
+
+	// Filter related signals
+	void filterPresetAdded(int index);
+	void filterPresetRemoved(int index);
+	void filterPresetChanged(int index);
+
 	// This signal is emited every time a command is executed.
 	// This is used to hide an old multi-dives-edited warning message.
 	// This is necessary, so that the user can't click on the "undo" button and undo
