@@ -2,34 +2,30 @@
 /*
  * divelistview.cpp
  *
- * classes for the divelist of Subsurface
+ * class for the divelist of Subsurface
  *
  */
 #include "qt-models/filtermodels.h"
 #include "desktop-widgets/modeldelegates.h"
 #include "desktop-widgets/mainwindow.h"
-#include "desktop-widgets/divepicturewidget.h"
 #include "core/selection.h"
-#include "core/divefilter.h"
-#include "core/divesite.h" // for dive_site_table. TODO: remove once adding pictures is undoified
 #include <unistd.h>
 #include <QSettings>
 #include <QKeyEvent>
 #include <QFileDialog>
-#include <QNetworkAccessManager>
-#include <QNetworkReply>
 #include <QStandardPaths>
 #include <QMessageBox>
 #include <QHeaderView>
 #include "commands/command.h"
+#include "commands/command_base.h"
 #include "core/errorhelper.h"
 #include "core/qthelper.h"
 #include "core/trip.h"
 #include "desktop-widgets/divelistview.h"
-#include "qt-models/divepicturemodel.h"
 #include "core/metrics.h"
 #include "desktop-widgets/simplewidgets.h"
 #include "desktop-widgets/mapwidget.h"
+#include "desktop-widgets/tripselectiondialog.h"
 
 DiveListView::DiveListView(QWidget *parent) : QTreeView(parent),
 	currentLayout(DiveTripModelBase::TREE),
@@ -454,10 +450,21 @@ void DiveListView::mouseReleaseEvent(QMouseEvent *event)
 
 void DiveListView::keyPressEvent(QKeyEvent *event)
 {
-	// Hook into cursor-up and cursor-down events and update selection if necessary.
-	// See comment in mouseReleaseEvent()
-	if (event->key() != Qt::Key_Down && event->key() != Qt::Key_Up)
-		return QTreeView::keyPressEvent(event);
+	// Hook into key events that change the selection (i.e. cursor-up, cursor-down,
+	// page-up, page-down, home and end) and update selection if necessary.
+	// See comment in mouseReleaseEvent().
+	switch (event->key()) {
+		case Qt::Key_Up:
+		case Qt::Key_Down:
+		case Qt::Key_PageUp:
+		case Qt::Key_PageDown:
+		case Qt::Key_Home:
+		case Qt::Key_End:
+			break;
+		default:
+			return QTreeView::keyPressEvent(event);
+	}
+
 	QModelIndexList selectionBefore = selectionModel()->selectedRows();
 	QTreeView::keyPressEvent(event);
 	QModelIndexList selectionAfter = selectionModel()->selectedRows();
@@ -557,7 +564,7 @@ void DiveListView::selectionChanged(const QItemSelection &selected, const QItemS
 			select_dives_in_trip(trip);
 			if (model->rowCount(index)) {
 				QItemSelection selection;
-				selection.select(index.child(0, 0), index.child(model->rowCount(index) - 1, 0));
+				selection.select(model->index(0, 0, index), model->index(model->rowCount(index) - 1, 0, index));
 				selectionModel()->select(selection, QItemSelectionModel::Select | QItemSelectionModel::Rows);
 				selectionModel()->setCurrentIndex(index, QItemSelectionModel::Select | QItemSelectionModel::NoUpdate);
 				if (!isExpanded(index))
@@ -603,16 +610,12 @@ static bool can_merge(const struct dive *a, const struct dive *b, enum asked_use
 
 void DiveListView::mergeDives()
 {
-	int i;
-	struct dive *d;
 	enum asked_user have_asked = NOTYET;
 
 	// Collect a vector of batches of dives to merge (i.e. a vector of vector of dives)
 	QVector<QVector<dive *>> merge_batches;
 	QVector<dive *> current_batch;
-	for_each_dive (i, d) {
-		if (!d->selected)
-			continue;
+	for (dive *d: getDiveSelection()) {
 		if (current_batch.empty()) {
 			current_batch.append(d);
 		} else if (can_merge(current_batch.back(), d, &have_asked)) {
@@ -632,19 +635,20 @@ void DiveListView::mergeDives()
 
 void DiveListView::splitDives()
 {
-	int i;
-	struct dive *dive;
-
-	// Let's collect the dives to be split first, so that we don't catch newly inserted dives!
-	QVector<struct dive *> dives;
-	for_each_dive (i, dive) {
-		if (dive->selected)
-			dives.append(dive);
-	}
-	for (struct dive *d: dives)
+	for (struct dive *d: getDiveSelection())
 		Command::splitDives(d, duration_t{-1});
 }
 
+void DiveListView::addDivesToTrip()
+{
+	TripSelectionDialog dialog(MainWindow::instance());
+	dive_trip *t = dialog.getTrip();
+	std::vector<dive *> dives = getDiveSelection();
+	if (!t || dives.empty())
+		return;
+	Command::addDivesToTrip(stdToQt<dive *>(dives), t);
+}
+
 void DiveListView::renumberDives()
 {
 	RenumberDialog dialog(true, MainWindow::instance());
@@ -731,16 +735,8 @@ void DiveListView::addToTrip(int delta)
 	if (!trip || !d)
 		// no dive, no trip? get me out of here
 		return;
-
-	QVector<dive *> dives;
-	if (d->selected) { // there are possibly other selected dives that we should add
-		int idx;
-		for_each_dive (idx, d) {
-			if (d->selected)
-				dives.append(d);
-		}
-	}
-	Command::addDivesToTrip(dives, trip);
+	std::vector<dive *> dives = getDiveSelection();
+	Command::addDivesToTrip(stdToQt<dive *>(dives), trip);
 }
 
 void DiveListView::markDiveInvalid()
@@ -758,14 +754,7 @@ void DiveListView::deleteDive()
 	struct dive *d = contextMenuIndex.data(DiveTripModelBase::DIVE_ROLE).value<struct dive *>();
 	if (!d)
 		return;
-
-	int i;
-	QVector<struct dive*> deletedDives;
-	for_each_dive (i, d) {
-		if (d->selected)
-			deletedDives.append(d);
-	}
-	Command::deleteDive(deletedDives);
+	Command::deleteDive(stdToQt<dive *>(getDiveSelection()));
 }
 
 void DiveListView::contextMenuEvent(QContextMenuEvent *event)
@@ -840,6 +829,7 @@ void DiveListView::contextMenuEvent(QContextMenuEvent *event)
 	if (amount_selected > 1 && consecutive_selected())
 		popup.addAction(tr("Merge selected dives"), this, &DiveListView::mergeDives);
 	if (amount_selected >= 1) {
+		popup.addAction(tr("Add dive(s) to arbitrary trip"), this, &DiveListView::addDivesToTrip);
 		popup.addAction(tr("Renumber dive(s)"), this, &DiveListView::renumberDives);
 		popup.addAction(tr("Shift dive times"), this, &DiveListView::shiftTimes);
 		popup.addAction(tr("Split selected dives"), this, &DiveListView::splitDives);
