@@ -37,7 +37,6 @@
 #include "core/settings/qPrefTechnicalDetails.h"
 
 #include "desktop-widgets/about.h"
-#include "desktop-widgets/divecomputermanagementdialog.h"
 #include "desktop-widgets/divelistview.h"
 #include "desktop-widgets/divelogexportdialog.h"
 #include "desktop-widgets/divelogimportdialog.h"
@@ -182,7 +181,7 @@ MainWindow::MainWindow() : QMainWindow(),
 	registerApplicationState(ApplicationState::EditDiveSite, { { diveSiteEdit, FLAG_NONE }, { profileContainer, FLAG_DISABLED },
 								   { diveList, FLAG_DISABLED }, { mapWidget, FLAG_NONE } });
 	registerApplicationState(ApplicationState::FilterDive, { { mainTab.get(), FLAG_NONE }, { profileContainer, FLAG_NONE },
-								 { diveList, FLAG_NONE },      { &filterWidget2, FLAG_NONE } });
+								 { diveList, FLAG_NONE },      { &filterWidget, FLAG_NONE } });
 	setApplicationState(ApplicationState::Default);
 
 	setWindowIcon(QIcon(":subsurface-icon"));
@@ -530,7 +529,7 @@ void MainWindow::on_actionCloudstorageopen_triggered()
 
 	showProgressBar();
 	QByteArray fileNamePtr = QFile::encodeName(filename);
-	if (!parse_file(fileNamePtr.data(), &dive_table, &trip_table, &dive_site_table))
+	if (!parse_file(fileNamePtr.data(), &dive_table, &trip_table, &dive_site_table, &device_table, &filter_preset_table))
 		setCurrentFile(fileNamePtr.data());
 	process_loaded_dives();
 	hideProgressBar();
@@ -568,15 +567,7 @@ void MainWindow::on_actionCloudstoragesave_triggered()
 		return;
 
 	setCurrentFile(qPrintable(filename));
-	setFileClean();
-}
-
-// Currently we have two markers for unsaved changes:
-// 1) unsaved_changes() returns true for non-undoable changes.
-// 2) Command::isClean() returns false for undoable changes.
-static bool unsavedChanges()
-{
-	return unsaved_changes() || !Command::isClean();
+	Command::setClean();
 }
 
 void MainWindow::on_actionCloudOnline_triggered()
@@ -598,7 +589,7 @@ void MainWindow::on_actionCloudOnline_triggered()
 	git_local_only = isOffline;
 	if (!isOffline) {
 		// User requests to go online. Try to sync cloud storage
-		if (unsavedChanges()) {
+		if (!Command::isClean()) {
 			// If there are unsaved changes, ask the user if they want to save them.
 			// If they don't, they have to sync manually.
 			if (QMessageBox::warning(this, tr("Save changes?"),
@@ -626,18 +617,12 @@ bool MainWindow::okToClose(QString message)
 		QMessageBox::warning(this, tr("Warning"), message);
 		return false;
 	}
-	if (unsavedChanges() && askSaveChanges() == false)
+	if (!Command::isClean() && askSaveChanges() == false)
 		return false;
 
 	return true;
 }
 
-void MainWindow::setFileClean()
-{
-	mark_divelist_changed(false);
-	Command::setClean();
-}
-
 void MainWindow::closeCurrentFile()
 {
 	/* free the dives and trips */
@@ -649,7 +634,7 @@ void MainWindow::closeCurrentFile()
 	if (!existing_filename)
 		setTitle();
 	disableShortcuts();
-	setFileClean();
+	Command::setClean();
 }
 
 void MainWindow::updateCloudOnlineStatus()
@@ -748,12 +733,6 @@ void MainWindow::on_actionDivelogs_de_triggered()
 	DivelogsDeWebServices::instance()->downloadDives();
 }
 
-void MainWindow::on_actionEditDeviceNames_triggered()
-{
-	DiveComputerManagementDialog::instance()->init();
-	DiveComputerManagementDialog::instance()->show();
-}
-
 bool MainWindow::plannerStateClean()
 {
 	if (progressDialog)
@@ -1310,7 +1289,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 		return;
 	}
 
-	if (unsavedChanges() && (askSaveChanges() == false)) {
+	if (!Command::isClean() && (askSaveChanges() == false)) {
 		event->ignore();
 		return;
 	}
@@ -1459,7 +1438,7 @@ int MainWindow::file_save_as(void)
 		return -1;
 
 	setCurrentFile(qPrintable(filename));
-	setFileClean();
+	Command::setClean();
 	addRecentFile(filename, true);
 	return 0;
 }
@@ -1496,7 +1475,7 @@ int MainWindow::file_save(void)
 	}
 	if (is_cloud)
 		hideProgressBar();
-	setFileClean();
+	Command::setClean();
 	addRecentFile(QString(existing_filename), true);
 	return 0;
 }
@@ -1535,8 +1514,8 @@ void MainWindow::setTitle()
 		return;
 	}
 
-	QString unsaved = (unsavedChanges() ? " *" : "");
-	QString shown = QString(" (%1)").arg(filterWidget2.shownText());
+	QString unsaved = (!Command::isClean() ? " *" : "");
+	QString shown = QString(" (%1)").arg(DiveFilter::instance()->shownText());
 	setWindowTitle("Subsurface: " + displayedFilename(existing_filename) + unsaved + shown);
 }
 
@@ -1549,13 +1528,15 @@ void MainWindow::importFiles(const QStringList fileNames)
 	struct dive_table table = empty_dive_table;
 	struct trip_table trips = empty_trip_table;
 	struct dive_site_table sites = empty_dive_site_table;
+	struct device_table devices;
+	struct filter_preset_table filter_presets;
 
 	for (int i = 0; i < fileNames.size(); ++i) {
 		fileNamePtr = QFile::encodeName(fileNames.at(i));
-		parse_file(fileNamePtr.data(), &table, &trips, &sites);
+		parse_file(fileNamePtr.data(), &table, &trips, &sites, &devices, &filter_presets);
 	}
 	QString source = fileNames.size() == 1 ? fileNames[0] : tr("multiple files");
-	Command::importDives(&table, &trips, &sites, IMPORT_MERGE_ALL_TRIPS, source);
+	Command::importDives(&table, &trips, &sites, &devices, &filter_presets, IMPORT_MERGE_ALL_TRIPS, source);
 }
 
 void MainWindow::loadFiles(const QStringList fileNames)
@@ -1569,7 +1550,7 @@ void MainWindow::loadFiles(const QStringList fileNames)
 	showProgressBar();
 	for (int i = 0; i < fileNames.size(); ++i) {
 		fileNamePtr = QFile::encodeName(fileNames.at(i));
-		if (!parse_file(fileNamePtr.data(), &dive_table, &trip_table, &dive_site_table)) {
+		if (!parse_file(fileNamePtr.data(), &dive_table, &trip_table, &dive_site_table, &device_table, &filter_preset_table)) {
 			setCurrentFile(fileNamePtr.data());
 			addRecentFile(fileNamePtr, false);
 		}
@@ -1643,10 +1624,12 @@ void MainWindow::on_actionImportDiveSites_triggered()
 	struct dive_table table = empty_dive_table;
 	struct trip_table trips = empty_trip_table;
 	struct dive_site_table sites = empty_dive_site_table;
+	struct device_table devices;
+	struct filter_preset_table filter_presets;
 
 	for (const QString &s: fileNames) {
 		QByteArray fileNamePtr = QFile::encodeName(s);
-		parse_file(fileNamePtr.data(), &table, &trips, &sites);
+		parse_file(fileNamePtr.data(), &table, &trips, &sites, &devices, &filter_presets);
 	}
 	// The imported dive sites still have pointers to imported dives - remove them
 	for (int i = 0; i < sites.nr; ++i)
