@@ -3,7 +3,7 @@
 #define MAPWIDGET_H
 
 #include "core/units.h"
-#include "core/subsurface-qt/DiveListNotifier.h"
+#include "core/subsurface-qt/divelistnotifier.h"
 #include <QQuickWidget>
 #include <QList>
 
