@@ -16,7 +16,6 @@
 #include "core/selection.h"
 #include "profile-widget/profilewidget2.h"
 #include "desktop-widgets/diveplanner.h"
-#include "core/divesitehelpers.h"
 #include "qt-models/divecomputerextradatamodel.h"
 #include "qt-models/divelocationmodel.h"
 #include "qt-models/filtermodels.h"
@@ -34,14 +33,12 @@
 #include "TabDivePhotos.h"
 #include "TabDiveStatistics.h"
 #include "TabDiveSite.h"
+#include "TabDiveComputer.h"
 
 #include <QCompleter>
-#include <QSettings>
 #include <QScrollBar>
 #include <QShortcut>
 #include <QMessageBox>
-#include <QDesktopServices>
-#include <QStringList>
 
 struct Completers {
 	QCompleter *divemaster;
@@ -49,6 +46,12 @@ struct Completers {
 	QCompleter *tags;
 };
 
+static bool paletteIsDark(const QPalette &p)
+{
+	// we consider a palette dark if the text color is lighter than the windows background
+	return p.window().color().valueF() < p.windowText().color().valueF();
+}
+
 MainTab::MainTab(QWidget *parent) : QTabWidget(parent),
 	editMode(false),
 	ignoreInput(false),
@@ -71,6 +74,14 @@ MainTab::MainTab(QWidget *parent) : QTabWidget(parent),
 	ui.tabWidget->addTab(extraWidgets.last(), tr("Extra Info"));
 	extraWidgets << new TabDiveSite(this);
 	ui.tabWidget->addTab(extraWidgets.last(), tr("Dive sites"));
+	extraWidgets << new TabDiveComputer(this);
+	ui.tabWidget->addTab(extraWidgets.last(), tr("Device names"));
+
+	// make sure we know if this is a light or dark mode
+	isDark = paletteIsDark(palette());
+
+	// call colorsChanged() for the initial setup now that the extraWidgets are loaded
+	colorsChanged();
 
 	updateDateTimeFields();
 
@@ -348,11 +359,12 @@ void MainTab::updateDiveInfo()
 	if (editMode || MainWindow::instance()->graphics->isPlanner())
 		return;
 
-	// If there is no current dive, disable all widgets except the last, which is the dive site tab.
-	// TODO: Conceptually, the dive site tab shouldn't even be a tab here!
+	// If there is no current dive, disable all widgets except the last two,
+	// which are the dive site tab and the dive computer tabs.
+	// TODO: Conceptually, these two shouldn't even be a tabs here!
 	bool enabled = current_dive != nullptr;
 	ui.notesTab->setEnabled(enabled);
-	for (int i = 0; i < extraWidgets.size() - 1; ++i)
+	for (int i = 0; i < extraWidgets.size() - 2; ++i)
 		extraWidgets[i]->setEnabled(enabled);
 
 	ignoreInput = true; // don't trigger on changes to the widgets
@@ -699,3 +711,44 @@ void MainTab::clearTabs()
 	for (auto widget: extraWidgets)
 		widget->clear();
 }
+
+void MainTab::changeEvent(QEvent *ev)
+{
+	if (ev->type() == QEvent::PaletteChange) {
+		// check if this is a light or dark mode
+		bool dark = paletteIsDark(palette());
+		if (dark != isDark) {
+			// things have changed, so setup the colors correctly
+			isDark = dark;
+			colorsChanged();
+		}
+	}
+	QTabWidget::changeEvent(ev);
+}
+
+// setup the colors of 'header' elements in the tab widget
+void MainTab::colorsChanged()
+{
+	QString colorText = isDark ? QStringLiteral("lightblue") : QStringLiteral("mediumblue");
+	QString lastpart = colorText + " ;}";
+
+	// only set the color if the widget is enabled
+	QString CSSLabelcolor = "QLabel:enabled { color: " + lastpart;
+	QString CSSTitlecolor = "QGroupBox::title:enabled { color: " + lastpart ;
+
+	// apply to all the group boxes
+	QList<QGroupBox *>groupBoxes = this->findChildren<QGroupBox *>();
+	for (QGroupBox *gb: groupBoxes)
+		gb->setStyleSheet(QString(CSSTitlecolor));
+
+	// apply to all labels that are marked as headers in the .ui file
+	QList<QLabel *>labels = this->findChildren<QLabel *>();
+	for (QLabel *ql: labels) {
+		if (ql->property("isHeader").toBool())
+			ql->setStyleSheet(QString(CSSLabelcolor));
+	}
+
+	// finally call the individual updateUi() functions so they can overwrite these style sheets
+	for (TabBase *widget: extraWidgets)
+		widget->updateUi(colorText);
+}
