@@ -29,12 +29,14 @@
 #include "core/errorhelper.h"
 #include "core/file.h"
 #include "core/divefilter.h"
+#include "core/filterconstraint.h"
 #include "core/qthelper.h"
 #include "core/qt-gui.h"
 #include "core/git-access.h"
 #include "core/cloudstorage.h"
 #include "core/membuffer.h"
 #include "core/downloadfromdcthread.h"
+#include "core/subsurfacestartup.h" // for ignore_bt flag
 #include "core/subsurface-string.h"
 #include "core/pref.h"
 #include "core/selection.h"
@@ -92,6 +94,23 @@ static void appendTextToLogStandalone(const char *text)
 		self->appendTextToLog(QString(text));
 }
 
+// This flag is set to true by operations that are not implemented in the
+// undo system. It is therefore only cleared on save and load.
+static bool dive_list_changed = false;
+
+void mark_divelist_changed(bool changed)
+{
+	if (dive_list_changed == changed)
+		return;
+	dive_list_changed = changed;
+	updateWindowTitle();
+}
+
+int unsaved_changes()
+{
+	return dive_list_changed;
+}
+
 // this callback is used from the uiNotification() function
 // the detour via callback allows us to keep the core code independent from QMLManager
 // I'm not sure it makes sense to have three different progress callbacks,
@@ -352,7 +371,7 @@ void QMLManager::openLocalThenRemote(QString url)
 	 * we try to open this), parse_file (which is called by openAndMaybeSync) will ALWAYS connect
 	 * to the remote and populate the cache.
 	 * Otherwise parse_file will respect the git_local_only flag and only update if that isn't set */
-	int error = parse_file(encodedFilename.constData(), &dive_table, &trip_table, &dive_site_table);
+	int error = parse_file(encodedFilename.constData(), &dive_table, &trip_table, &dive_site_table, &device_table, &filter_preset_table);
 	if (error) {
 		/* there can be 2 reasons for this:
 		 * 1) we have cloud credentials, but there is no local repo (yet).
@@ -450,8 +469,11 @@ void QMLManager::mergeLocalRepo()
 	struct dive_table table = empty_dive_table;
 	struct trip_table trips = empty_trip_table;
 	struct dive_site_table sites = empty_dive_site_table;
-	parse_file(qPrintable(nocloud_localstorage()), &table, &trips, &sites);
-	add_imported_dives(&table, &trips, &sites, IMPORT_MERGE_ALL_TRIPS);
+	struct device_table devices;
+	struct filter_preset_table filter_presets;
+	parse_file(qPrintable(nocloud_localstorage()), &table, &trips, &sites, &devices, &filter_presets);
+	add_imported_dives(&table, &trips, &sites, &devices, IMPORT_MERGE_ALL_TRIPS);
+	mark_divelist_changed(true);
 }
 
 void QMLManager::copyAppLogToClipboard()
@@ -524,7 +546,7 @@ void QMLManager::finishSetup()
 		qPrefCloudStorage::set_cloud_verification_status(qPrefCloudStorage::CS_NOCLOUD);
 		saveCloudCredentials(qPrefCloudStorage::cloud_storage_email(), qPrefCloudStorage::cloud_storage_password(), qPrefCloudStorage::cloud_storage_pin());
 		appendTextToLog(tr("working in no-cloud mode"));
-		int error = parse_file(existing_filename, &dive_table, &trip_table, &dive_site_table);
+		int error = parse_file(existing_filename, &dive_table, &trip_table, &dive_site_table, &device_table, &filter_preset_table);
 		if (error) {
 			// we got an error loading the local file
 			setNotificationText(tr("Error parsing local storage, giving up"));
@@ -705,10 +727,10 @@ void QMLManager::loadDivesWithValidCredentials()
 		}
 		if (git != dummy_git_repository) {
 			appendTextToLog(QString("have repository and branch %1").arg(branch));
-			error = git_load_dives(git, branch, &dive_table, &trip_table, &dive_site_table);
+			error = git_load_dives(git, branch, &dive_table, &trip_table, &dive_site_table, &device_table, &filter_preset_table);
 		} else {
 			appendTextToLog(QString("didn't receive valid git repo, try again"));
-			error = parse_file(fileNamePrt.data(), &dive_table, &trip_table, &dive_site_table);
+			error = parse_file(fileNamePrt.data(), &dive_table, &trip_table, &dive_site_table, &device_table, &filter_preset_table);
 		}
 		setDiveListProcessing(false);
 		if (!error) {
@@ -1414,7 +1436,7 @@ void QMLManager::selectDive(int id)
 			amount_selected++;
 	}
 	if (amount_selected == 0)
-		qWarning("QManager::selectDive() called with unknown id");
+		qWarning("QManager::selectDive() called with unknown id %d",id);
 }
 
 void QMLManager::deleteDive(int id)
@@ -2084,6 +2106,13 @@ void QMLManager::restartDownload(QAndroidJniObject usbDevice)
 
 #endif
 
+static filter_constraint make_filter_constraint(filter_constraint_type type, const QString &s)
+{
+	filter_constraint res(type);
+	filter_constraint_set_stringlist(res, s);
+	return res;
+}
+
 void QMLManager::setFilter(const QString filterText, int index)
 {
 	QString f = filterText.trimmed();
@@ -2091,15 +2120,17 @@ void QMLManager::setFilter(const QString filterText, int index)
 	if (!f.isEmpty()) {
 		// This is ugly - the indices of the mode are hardcoded!
 		switch(index) {
-			default:
-			case 0: data.mode = FilterData::Mode::FULLTEXT; break;
-			case 1: data.mode = FilterData::Mode::PEOPLE; break;
-			case 2: data.mode = FilterData::Mode::TAGS; break;
-		}
-		if (data.mode == FilterData::Mode::FULLTEXT)
+		default:
+		case 0:
 			data.fullText = f;
-		else
-			data.tags = f.split(",", QString::SkipEmptyParts);
+			break;
+		case 1:
+			data.constraints.push_back(make_filter_constraint(FILTER_CONSTRAINT_PEOPLE, f));
+			break;
+		case 2:
+			data.constraints.push_back(make_filter_constraint(FILTER_CONSTRAINT_TAGS, f));
+			break;
+		}
 	}
 	DiveFilter::instance()->setFilter(data);
 }
@@ -2225,10 +2256,12 @@ void QMLManager::importCacheRepo(QString repo)
 	struct dive_table table = empty_dive_table;
 	struct trip_table trips = empty_trip_table;
 	struct dive_site_table sites = empty_dive_site_table;
+	struct device_table devices;
+	struct filter_preset_table filter_presets;
 	QString repoPath = QString("%1/cloudstorage/%2").arg(system_default_directory()).arg(repo);
 	appendTextToLog(QString("importing %1").arg(repoPath));
-	parse_file(qPrintable(repoPath), &table, &trips, &sites);
-	add_imported_dives(&table, &trips, &sites, IMPORT_MERGE_ALL_TRIPS);
+	parse_file(qPrintable(repoPath), &table, &trips, &sites, &devices, &filter_presets);
+	add_imported_dives(&table, &trips, &sites, &devices, IMPORT_MERGE_ALL_TRIPS);
 	changesNeedSaving();
 }
 
