@@ -21,11 +21,10 @@ public:
 	void setPlotInfo(const struct plot_info &info);
 	void recalculate();
 
-protected:
-	void mouseMoveEvent(QGraphicsSceneMouseEvent *event) override;
 private:
+	void mouseMoveEvent(QGraphicsSceneMouseEvent *event) override;
 	struct plot_info pInfo;
-	struct plot_data *entry;
+	int idx;
 	RulerItem2 *ruler;
 	DiveCartesianAxis *timeAxis;
 	DiveCartesianAxis *depthAxis;
