@@ -7,13 +7,17 @@
 
 DivePlotDataModel::DivePlotDataModel(QObject *parent) :
 	QAbstractTableModel(parent),
-	diveId(0),
 	dcNr(0)
 {
 	init_plot_info(&pInfo);
 	memset(&plot_deco_state, 0, sizeof(struct deco_state));
 }
 
+DivePlotDataModel::~DivePlotDataModel()
+{
+	free_plot_info_data(&pInfo);
+}
+
 int DivePlotDataModel::columnCount(const QModelIndex&) const
 {
 	return COLUMNS;
@@ -32,7 +36,7 @@ QVariant DivePlotDataModel::data(const QModelIndex &index, int role) const
 		case TIME:
 			return item.sec;
 		case PRESSURE:
-			return item.pressure[0][0];
+			return get_plot_sensor_pressure(&pInfo, index.row(), 0);
 		case TEMPERATURE:
 			return item.temperature;
 		case COLOR:
@@ -40,9 +44,9 @@ QVariant DivePlotDataModel::data(const QModelIndex &index, int role) const
 		case USERENTERED:
 			return false;
 		case SENSOR_PRESSURE:
-			return item.pressure[0][0];
+			return get_plot_sensor_pressure(&pInfo, index.row(), 0);
 		case INTERPOLATED_PRESSURE:
-			return item.pressure[0][1];
+			return get_plot_interpolated_pressure(&pInfo, index.row(), 0);
 		case CEILING:
 			return item.ceiling;
 		case SAC:
@@ -168,8 +172,9 @@ void DivePlotDataModel::clear()
 		beginRemoveRows(QModelIndex(), 0, rowCount() - 1);
 		pInfo.nr = 0;
 		free(pInfo.entry);
-		pInfo.entry = 0;
-		diveId = -1;
+		free(pInfo.pressures);
+		pInfo.entry = nullptr;
+		pInfo.pressures = nullptr;
 		dcNr = -1;
 		endRemoveRows();
 	}
@@ -177,16 +182,16 @@ void DivePlotDataModel::clear()
 
 void DivePlotDataModel::setDive(dive *d, const plot_info &info)
 {
-	clear();
-	Q_ASSERT(d != NULL);
-	diveId = d->id;
+	beginResetModel();
 	dcNr = dc_number;
 	free(pInfo.entry);
+	free(pInfo.pressures);
 	pInfo = info;
-	pInfo.entry = (struct plot_data *)malloc(sizeof(struct plot_data) * pInfo.nr);
+	pInfo.entry = (plot_data *)malloc(sizeof(plot_data) * pInfo.nr);
 	memcpy(pInfo.entry, info.entry, sizeof(plot_data) * pInfo.nr);
-	beginInsertRows(QModelIndex(), 0, pInfo.nr - 1);
-	endInsertRows();
+	pInfo.pressures = (plot_pressure_data *)malloc(sizeof(plot_pressure_data) * pInfo.nr_cylinders * pInfo.nr);
+	memcpy(pInfo.pressures, info.pressures, sizeof(plot_pressure_data) * pInfo.nr_cylinders * pInfo.nr);
+	endResetModel();
 }
 
 unsigned int DivePlotDataModel::dcShown() const
@@ -199,8 +204,8 @@ unsigned int DivePlotDataModel::dcShown() const
 	{                                                             \
 		double ret = -1;                                      \
 		for (int i = 0, count = rowCount(); i < count; i++) { \
-			if (pInfo.entry[i].pressures.GAS > ret)                 \
-				ret = pInfo.entry[i].pressures.GAS;             \
+			if (pInfo.entry[i].pressures.GAS > ret)       \
+				ret = pInfo.entry[i].pressures.GAS;   \
 		}                                                     \
 		return ret;                                           \
 	}
