@@ -119,14 +119,10 @@ QVariant DiveTripModelBase::tripData(const dive_trip *trip, int column, int role
 		switch (column) {
 		case DiveTripModelBase::NR:
 			QString shownText;
-			bool oneDayTrip = trip_is_single_day(trip);
 			int countShown = trip_shown_dives(trip);
 			if (countShown < trip->dives.nr)
 				shownText = tr("(%1 shown)").arg(countShown);
-			if (!empty_string(trip->location))
-				return QString(trip->location) + ", " + get_trip_date_string(trip_date(trip), trip->dives.nr, oneDayTrip) + " "+ shownText;
-			else
-				return get_trip_date_string(trip_date(trip), trip->dives.nr, oneDayTrip) + shownText;
+			return get_trip_string(trip) + " " + shownText;
 		}
 	}
 
@@ -538,9 +534,6 @@ static ShownChange updateShownAll()
 
 void DiveTripModelBase::currentChanged()
 {
-	if (oldCurrent == current_dive)
-		return;
-
 	// On Desktop we use a signal to forward current-dive changed, on mobile we use ROLE_CURRENT.
 	// TODO: Unify - use the role for both.
 #if defined(SUBSURFACE_MOBILE)
@@ -549,11 +542,13 @@ void DiveTripModelBase::currentChanged()
 		QModelIndex oldIdx = diveToIdx(oldCurrent);
 		dataChanged(oldIdx, oldIdx, roles);
 	}
-	if (current_dive) {
+	if (current_dive && oldCurrent != current_dive) {
 		QModelIndex newIdx = diveToIdx(current_dive);
 		dataChanged(newIdx, newIdx, roles);
 	}
 #else
+	if (oldCurrent == current_dive)
+		return;
 	if (current_dive) {
 		QModelIndex newIdx = diveToIdx(current_dive);
 		emit currentDiveChanged(newIdx);
@@ -721,6 +716,8 @@ void DiveTripModelTree::populate()
 	uiNotification(QObject::tr("start processing"));
 	for (int i = 0; i < dive_table.nr; ++i) {
 		dive *d = get_dive(i);
+		if (!d) // should never happen
+			continue;
 		update_cylinder_related_info(d);
 		if (d->hidden_by_filter)
 			continue;
@@ -1330,8 +1327,8 @@ void DiveTripModelTree::divesMovedBetweenTrips(dive_trip *from, dive_trip *to, b
 	// Cheating!
 	// Unfortunately, removing the dives means that their selection is lost.
 	// Thus, remember the selection and re-add it later.
-	divesAdded(to, createTo, dives);
 	divesDeletedInternal(from, deleteFrom, dives); // Use internal version to keep current dive
+	divesAdded(to, createTo, dives);
 }
 
 void DiveTripModelTree::divesTimeChanged(timestamp_t delta, const QVector<dive *> &dives)
@@ -1487,7 +1484,7 @@ void DiveTripModelList::populate()
 	items.reserve(dive_table.nr);
 	for (int i = 0; i < dive_table.nr; ++i) {
 		dive *d = get_dive(i);
-		if (d->hidden_by_filter)
+		if (!d || d->hidden_by_filter)
 			continue;
 		items.push_back(d);
 	}
